@@ -1,4 +1,4 @@
-__version__ = '1.5.0'
+__version__ = '1.5.1'
 
 import logging
 logging.basicConfig()
@@ -37,3 +37,5 @@ contracts = contract
 from .library import miscellaneous_aliases
 
 
+# And after everything else is loaded, load the  utils
+from .useful_contracts import *
