@@ -14,7 +14,7 @@ from . import variables_tc
 from . import simple_values_tc
 from . import map_tc
 from . import seq_tc
-#from . import attr_tc
+from . import attr_tc
 
 try:
     import numpy
