@@ -1,19 +1,19 @@
 from numpy import zeros, ones
-import numpy
+import numpy as np
 
 from . import syntax_fail, good, fail
 
-a_u8 = numpy.zeros((3, 4), dtype='uint8')
-a_i8 = numpy.zeros((3, 4), dtype='int8')
-a_u16 = numpy.zeros((3, 4), dtype='uint16')
-a_i16 = numpy.zeros((3, 4), dtype='int16')
-a_u32 = numpy.zeros((3, 4), dtype='uint32')
-a_i32 = numpy.zeros((3, 4), dtype='int32')
-a_f32 = numpy.zeros((3, 4), dtype='float32')
-a_f64 = numpy.zeros((3, 4), dtype='float64')
-a_bool = numpy.zeros((3, 4), dtype='bool')
+a_u8 = np.zeros((3, 4), dtype='uint8')
+a_i8 = np.zeros((3, 4), dtype='int8')
+a_u16 = np.zeros((3, 4), dtype='uint16')
+a_i16 = np.zeros((3, 4), dtype='int16')
+a_u32 = np.zeros((3, 4), dtype='uint32')
+a_i32 = np.zeros((3, 4), dtype='int32')
+a_f32 = np.zeros((3, 4), dtype='float32')
+a_f64 = np.zeros((3, 4), dtype='float64')
+a_bool = np.zeros((3, 4), dtype='bool')
 
-### Strings
+# ## Strings
 good('array', a_f32)
 good('array', a_f64)
 # synonims
@@ -34,10 +34,10 @@ fail('array(uint8)', a_f32)
 fail('array(float32)', a_u8)
 
 # shapes
-a0d = numpy.zeros((), dtype='float32')
-a1d = numpy.zeros((2,))
-a2d = numpy.zeros((2, 4,))
-a3d = numpy.zeros((2, 4, 8))
+a0d = np.zeros((), dtype='float32')
+a1d = np.zeros((2,))
+a2d = np.zeros((2, 4,))
+a3d = np.zeros((2, 4, 8))
 
 good('shape[0]', a0d)
 good('shape[1]', a1d)
@@ -83,8 +83,8 @@ good('array[XxYx...],X=2,Y=4', a3d)
 
 # Using the array syntax  array[shape desc]
 
-v1d = numpy.zeros(100)
-v2d = numpy.zeros((10, 10))
+v1d = np.zeros(100)
+v2d = np.zeros((10, 10))
 good('array[100]', v1d)
 fail('array[100]', v2d)
 good('array[10x10]', v2d)
@@ -105,49 +105,52 @@ good('shape[3]', a3d)
 good('array[1x2]', zeros((1, 2)))
 
 # Now: special comparisons for arrays
-A = numpy.array([0, 1, 2])
-B = numpy.array([10, 20, 30])
+A = np.array([0, 1, 2])
+B = np.array([10, 20, 30])
 good('array(>=0)', A)
 good('array(<=2)', A)
 fail('array(<=20)', B)
 good('array(=0)', zeros((10)))
-fail('array(=0)', numpy.array([0, 1, 0]))
+fail('array(=0)', np.array([0, 1, 0]))
 good('array(=1)', ones((10)))
 
 good(['shape(x)', 'shape(x)'], [a2d, a2d])
 fail(['shape(x)', 'shape(x)'], [a2d, a3d])
 
-good('array[NxN](<=1)', numpy.ones((10, 10)))
-good('array[NxN](<=1,float32)', numpy.ones((10, 10), dtype='float32'))
-good('array[NxN](<=1,float32|float64)', numpy.ones((10, 10), dtype='float64'))
+good('array[NxN](<=1)', np.ones((10, 10)))
+good('array[NxN](<=1,float32)', np.ones((10, 10), dtype='float32'))
+good('array[NxN](<=1,float32|float64)', np.ones((10, 10), dtype='float64'))
 good('array[NxN](<=1,(float32|float64))',
-     numpy.ones((10, 10), dtype='float64'))
-good('array[NxN](<=1,>=1)', numpy.ones((10, 10)))
+     np.ones((10, 10), dtype='float64'))
+good('array[NxN](<=1,>=1)', np.ones((10, 10)))
 
 # more complicated tests
 
-good('array[(2|3)xN]', numpy.ones((2, 10)))
-good('array[(2|3)xN]', numpy.ones((3, 10)))
-fail('array[(2|3)xN]', numpy.ones((4, 10)))
-good('array[(2|3)x...]', numpy.ones((2, 10)))
-good('array[(2|3)x...]', numpy.ones((3, 10)))
-fail('array[(2|3)x...]', numpy.ones((4, 10)))
-
-good('array[(2,*)xN]', numpy.ones((2, 10)))
-fail('array[(2,3)xN]', numpy.ones((4, 10)))
-good('array[(2,*)x...]', numpy.ones((2, 10)))
-fail('array[(2,3)x...]', numpy.ones((4, 10)))
-
-
-good('seq', numpy.ones(3))
-good('seq[3]', numpy.ones(3))
-fail('seq[3]', numpy.ones(2))
-good('seq[6]', numpy.ones((2, 3)))
-fail('seq[6]', numpy.ones((2, 4)))
-
-
+good('array[(2|3)xN]', np.ones((2, 10)))
+good('array[(2|3)xN]', np.ones((3, 10)))
+fail('array[(2|3)xN]', np.ones((4, 10)))
+good('array[(2|3)x...]', np.ones((2, 10)))
+good('array[(2|3)x...]', np.ones((3, 10)))
+fail('array[(2|3)x...]', np.ones((4, 10)))
 
+good('array[(2,*)xN]', np.ones((2, 10)))
+fail('array[(2,3)xN]', np.ones((4, 10)))
+good('array[(2,*)x...]', np.ones((2, 10)))
+fail('array[(2,3)x...]', np.ones((4, 10)))
 
 
+good('seq', np.ones(3))
+good('seq[3]', np.ones(3))
+fail('seq[3]', np.ones(2))
+good('seq[6]', np.ones((2, 3)))
+fail('seq[6]', np.ones((2, 4)))
+
+# "finite" contract 
+good('finite', 1)
+good('finite', 0)
+good('finite', -1)
+good('finite', np.float(1))
+fail('finite', np.inf)
+fail('finite', np.nan)
 
 
